/****************************************************************************
** Meta object code from reading C++ file 'notification.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "notification.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'notification.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Notification_t {
    QByteArrayData data[75];
    char stringdata0[968];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Notification_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Notification_t qt_meta_stringdata_Notification = {
    {
QT_MOC_LITERAL(0, 0, 12), // "Notification"
QT_MOC_LITERAL(1, 13, 7), // "clicked"
QT_MOC_LITERAL(2, 21, 0), // ""
QT_MOC_LITERAL(3, 22, 6), // "closed"
QT_MOC_LITERAL(4, 29, 6), // "reason"
QT_MOC_LITERAL(5, 36, 15), // "categoryChanged"
QT_MOC_LITERAL(6, 52, 14), // "appNameChanged"
QT_MOC_LITERAL(7, 67, 17), // "replacesIdChanged"
QT_MOC_LITERAL(8, 85, 11), // "iconChanged"
QT_MOC_LITERAL(9, 97, 14), // "appIconChanged"
QT_MOC_LITERAL(10, 112, 14), // "summaryChanged"
QT_MOC_LITERAL(11, 127, 11), // "bodyChanged"
QT_MOC_LITERAL(12, 139, 14), // "urgencyChanged"
QT_MOC_LITERAL(13, 154, 20), // "expireTimeoutChanged"
QT_MOC_LITERAL(14, 175, 16), // "timestampChanged"
QT_MOC_LITERAL(15, 192, 21), // "previewSummaryChanged"
QT_MOC_LITERAL(16, 214, 18), // "previewBodyChanged"
QT_MOC_LITERAL(17, 233, 16), // "itemCountChanged"
QT_MOC_LITERAL(18, 250, 20), // "remoteActionsChanged"
QT_MOC_LITERAL(19, 271, 21), // "remoteDBusCallChanged"
QT_MOC_LITERAL(20, 293, 13), // "originChanged"
QT_MOC_LITERAL(21, 307, 22), // "maxContentLinesChanged"
QT_MOC_LITERAL(22, 330, 18), // "isTransientChanged"
QT_MOC_LITERAL(23, 349, 15), // "progressChanged"
QT_MOC_LITERAL(24, 365, 18), // "checkActionInvoked"
QT_MOC_LITERAL(25, 384, 2), // "id"
QT_MOC_LITERAL(26, 387, 9), // "actionKey"
QT_MOC_LITERAL(27, 397, 23), // "checkNotificationClosed"
QT_MOC_LITERAL(28, 421, 7), // "publish"
QT_MOC_LITERAL(29, 429, 5), // "close"
QT_MOC_LITERAL(30, 435, 13), // "notifications"
QT_MOC_LITERAL(31, 449, 15), // "QList<QObject*>"
QT_MOC_LITERAL(32, 465, 5), // "owner"
QT_MOC_LITERAL(33, 471, 23), // "notificationsByCategory"
QT_MOC_LITERAL(34, 495, 8), // "category"
QT_MOC_LITERAL(35, 504, 12), // "remoteAction"
QT_MOC_LITERAL(36, 517, 4), // "name"
QT_MOC_LITERAL(37, 522, 11), // "displayName"
QT_MOC_LITERAL(38, 534, 7), // "service"
QT_MOC_LITERAL(39, 542, 4), // "path"
QT_MOC_LITERAL(40, 547, 5), // "iface"
QT_MOC_LITERAL(41, 553, 6), // "method"
QT_MOC_LITERAL(42, 560, 9), // "arguments"
QT_MOC_LITERAL(43, 570, 7), // "appName"
QT_MOC_LITERAL(44, 578, 10), // "replacesId"
QT_MOC_LITERAL(45, 589, 4), // "icon"
QT_MOC_LITERAL(46, 594, 7), // "appIcon"
QT_MOC_LITERAL(47, 602, 7), // "summary"
QT_MOC_LITERAL(48, 610, 4), // "body"
QT_MOC_LITERAL(49, 615, 7), // "urgency"
QT_MOC_LITERAL(50, 623, 7), // "Urgency"
QT_MOC_LITERAL(51, 631, 13), // "expireTimeout"
QT_MOC_LITERAL(52, 645, 9), // "timestamp"
QT_MOC_LITERAL(53, 655, 14), // "previewSummary"
QT_MOC_LITERAL(54, 670, 11), // "previewBody"
QT_MOC_LITERAL(55, 682, 9), // "itemCount"
QT_MOC_LITERAL(56, 692, 25), // "remoteDBusCallServiceName"
QT_MOC_LITERAL(57, 718, 24), // "remoteDBusCallObjectPath"
QT_MOC_LITERAL(58, 743, 23), // "remoteDBusCallInterface"
QT_MOC_LITERAL(59, 767, 24), // "remoteDBusCallMethodName"
QT_MOC_LITERAL(60, 792, 23), // "remoteDBusCallArguments"
QT_MOC_LITERAL(61, 816, 13), // "remoteActions"
QT_MOC_LITERAL(62, 830, 6), // "origin"
QT_MOC_LITERAL(63, 837, 15), // "maxContentLines"
QT_MOC_LITERAL(64, 853, 11), // "isTransient"
QT_MOC_LITERAL(65, 865, 8), // "progress"
QT_MOC_LITERAL(66, 874, 3), // "Low"
QT_MOC_LITERAL(67, 878, 6), // "Normal"
QT_MOC_LITERAL(68, 885, 8), // "Critical"
QT_MOC_LITERAL(69, 894, 11), // "CloseReason"
QT_MOC_LITERAL(70, 906, 7), // "Expired"
QT_MOC_LITERAL(71, 914, 15), // "DismissedByUser"
QT_MOC_LITERAL(72, 930, 6), // "Closed"
QT_MOC_LITERAL(73, 937, 8), // "Progress"
QT_MOC_LITERAL(74, 946, 21) // "ProgressIndeterminate"

    },
    "Notification\0clicked\0\0closed\0reason\0"
    "categoryChanged\0appNameChanged\0"
    "replacesIdChanged\0iconChanged\0"
    "appIconChanged\0summaryChanged\0bodyChanged\0"
    "urgencyChanged\0expireTimeoutChanged\0"
    "timestampChanged\0previewSummaryChanged\0"
    "previewBodyChanged\0itemCountChanged\0"
    "remoteActionsChanged\0remoteDBusCallChanged\0"
    "originChanged\0maxContentLinesChanged\0"
    "isTransientChanged\0progressChanged\0"
    "checkActionInvoked\0id\0actionKey\0"
    "checkNotificationClosed\0publish\0close\0"
    "notifications\0QList<QObject*>\0owner\0"
    "notificationsByCategory\0category\0"
    "remoteAction\0name\0displayName\0service\0"
    "path\0iface\0method\0arguments\0appName\0"
    "replacesId\0icon\0appIcon\0summary\0body\0"
    "urgency\0Urgency\0expireTimeout\0timestamp\0"
    "previewSummary\0previewBody\0itemCount\0"
    "remoteDBusCallServiceName\0"
    "remoteDBusCallObjectPath\0"
    "remoteDBusCallInterface\0"
    "remoteDBusCallMethodName\0"
    "remoteDBusCallArguments\0remoteActions\0"
    "origin\0maxContentLines\0isTransient\0"
    "progress\0Low\0Normal\0Critical\0CloseReason\0"
    "Expired\0DismissedByUser\0Closed\0Progress\0"
    "ProgressIndeterminate"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Notification[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      30,   14, // methods
      23,  234, // properties
       3,  326, // enums/sets
       0,    0, // constructors
       0,       // flags
      21,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  164,    2, 0x06 /* Public */,
       3,    1,  165,    2, 0x06 /* Public */,
       5,    0,  168,    2, 0x06 /* Public */,
       6,    0,  169,    2, 0x06 /* Public */,
       7,    0,  170,    2, 0x06 /* Public */,
       8,    0,  171,    2, 0x06 /* Public */,
       9,    0,  172,    2, 0x06 /* Public */,
      10,    0,  173,    2, 0x06 /* Public */,
      11,    0,  174,    2, 0x06 /* Public */,
      12,    0,  175,    2, 0x06 /* Public */,
      13,    0,  176,    2, 0x06 /* Public */,
      14,    0,  177,    2, 0x06 /* Public */,
      15,    0,  178,    2, 0x06 /* Public */,
      16,    0,  179,    2, 0x06 /* Public */,
      17,    0,  180,    2, 0x06 /* Public */,
      18,    0,  181,    2, 0x06 /* Public */,
      19,    0,  182,    2, 0x06 /* Public */,
      20,    0,  183,    2, 0x06 /* Public */,
      21,    0,  184,    2, 0x06 /* Public */,
      22,    0,  185,    2, 0x06 /* Public */,
      23,    0,  186,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      24,    2,  187,    2, 0x08 /* Private */,
      27,    2,  192,    2, 0x08 /* Private */,

 // methods: name, argc, parameters, tag, flags
      28,    0,  197,    2, 0x02 /* Public */,
      29,    0,  198,    2, 0x02 /* Public */,
      30,    0,  199,    2, 0x02 /* Public */,
      30,    1,  200,    2, 0x02 /* Public */,
      33,    1,  203,    2, 0x02 /* Public */,
      35,    7,  206,    2, 0x02 /* Public */,
      35,    6,  221,    2, 0x22 /* Public | MethodCloned */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::UInt,    4,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::UInt, QMetaType::QString,   25,   26,
    QMetaType::Void, QMetaType::UInt, QMetaType::UInt,   25,    4,

 // methods: parameters
    QMetaType::Void,
    QMetaType::Void,
    0x80000000 | 31,
    0x80000000 | 31, QMetaType::QString,   32,
    0x80000000 | 31, QMetaType::QString,   34,
    QMetaType::QVariant, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QVariantList,   36,   37,   38,   39,   40,   41,   42,
    QMetaType::QVariant, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString,   36,   37,   38,   39,   40,   41,

 // properties: name, type, flags
      34, QMetaType::QString, 0x00495103,
      43, QMetaType::QString, 0x00495103,
      44, QMetaType::UInt, 0x00495103,
      45, QMetaType::QString, 0x00495103,
      46, QMetaType::QString, 0x00495103,
      47, QMetaType::QString, 0x00495103,
      48, QMetaType::QString, 0x00495103,
      49, 0x80000000 | 50, 0x0049510b,
      51, QMetaType::Int, 0x00495103,
      52, QMetaType::QDateTime, 0x00495103,
      53, QMetaType::QString, 0x00495103,
      54, QMetaType::QString, 0x00495103,
      55, QMetaType::Int, 0x00495103,
      56, QMetaType::QString, 0x00495103,
      57, QMetaType::QString, 0x00495103,
      58, QMetaType::QString, 0x00495103,
      59, QMetaType::QString, 0x00495103,
      60, QMetaType::QVariantList, 0x00495103,
      61, QMetaType::QVariantList, 0x00495103,
      62, QMetaType::QString, 0x00495103,
      63, QMetaType::Int, 0x00495103,
      64, QMetaType::Bool, 0x00495103,
      65, QMetaType::QVariant, 0x00495107,

 // properties: notify_signal_id
       2,
       3,
       4,
       5,
       6,
       7,
       8,
       9,
      10,
      11,
      12,
      13,
      14,
      16,
      16,
      16,
      16,
      16,
      15,
      17,
      18,
      19,
      20,

 // enums: name, alias, flags, count, data
      50,   50, 0x0,    3,  341,
      69,   69, 0x0,    3,  347,
      73,   73, 0x0,    1,  353,

 // enum data: key, value
      66, uint(Notification::Low),
      67, uint(Notification::Normal),
      68, uint(Notification::Critical),
      70, uint(Notification::Expired),
      71, uint(Notification::DismissedByUser),
      72, uint(Notification::Closed),
      74, uint(Notification::ProgressIndeterminate),

       0        // eod
};

void Notification::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<Notification *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->clicked(); break;
        case 1: _t->closed((*reinterpret_cast< uint(*)>(_a[1]))); break;
        case 2: _t->categoryChanged(); break;
        case 3: _t->appNameChanged(); break;
        case 4: _t->replacesIdChanged(); break;
        case 5: _t->iconChanged(); break;
        case 6: _t->appIconChanged(); break;
        case 7: _t->summaryChanged(); break;
        case 8: _t->bodyChanged(); break;
        case 9: _t->urgencyChanged(); break;
        case 10: _t->expireTimeoutChanged(); break;
        case 11: _t->timestampChanged(); break;
        case 12: _t->previewSummaryChanged(); break;
        case 13: _t->previewBodyChanged(); break;
        case 14: _t->itemCountChanged(); break;
        case 15: _t->remoteActionsChanged(); break;
        case 16: _t->remoteDBusCallChanged(); break;
        case 17: _t->originChanged(); break;
        case 18: _t->maxContentLinesChanged(); break;
        case 19: _t->isTransientChanged(); break;
        case 20: _t->progressChanged(); break;
        case 21: _t->checkActionInvoked((*reinterpret_cast< uint(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2]))); break;
        case 22: _t->checkNotificationClosed((*reinterpret_cast< uint(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2]))); break;
        case 23: _t->publish(); break;
        case 24: _t->close(); break;
        case 25: { QList<QObject*> _r = _t->notifications();
            if (_a[0]) *reinterpret_cast< QList<QObject*>*>(_a[0]) = std::move(_r); }  break;
        case 26: { QList<QObject*> _r = _t->notifications((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QList<QObject*>*>(_a[0]) = std::move(_r); }  break;
        case 27: { QList<QObject*> _r = _t->notificationsByCategory((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QList<QObject*>*>(_a[0]) = std::move(_r); }  break;
        case 28: { QVariant _r = _t->remoteAction((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5])),(*reinterpret_cast< const QString(*)>(_a[6])),(*reinterpret_cast< const QVariantList(*)>(_a[7])));
            if (_a[0]) *reinterpret_cast< QVariant*>(_a[0]) = std::move(_r); }  break;
        case 29: { QVariant _r = _t->remoteAction((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5])),(*reinterpret_cast< const QString(*)>(_a[6])));
            if (_a[0]) *reinterpret_cast< QVariant*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (Notification::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Notification::clicked)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (Notification::*)(uint );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Notification::closed)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (Notification::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Notification::categoryChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (Notification::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Notification::appNameChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (Notification::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Notification::replacesIdChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (Notification::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Notification::iconChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (Notification::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Notification::appIconChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (Notification::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Notification::summaryChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (Notification::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Notification::bodyChanged)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (Notification::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Notification::urgencyChanged)) {
                *result = 9;
                return;
            }
        }
        {
            using _t = void (Notification::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Notification::expireTimeoutChanged)) {
                *result = 10;
                return;
            }
        }
        {
            using _t = void (Notification::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Notification::timestampChanged)) {
                *result = 11;
                return;
            }
        }
        {
            using _t = void (Notification::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Notification::previewSummaryChanged)) {
                *result = 12;
                return;
            }
        }
        {
            using _t = void (Notification::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Notification::previewBodyChanged)) {
                *result = 13;
                return;
            }
        }
        {
            using _t = void (Notification::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Notification::itemCountChanged)) {
                *result = 14;
                return;
            }
        }
        {
            using _t = void (Notification::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Notification::remoteActionsChanged)) {
                *result = 15;
                return;
            }
        }
        {
            using _t = void (Notification::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Notification::remoteDBusCallChanged)) {
                *result = 16;
                return;
            }
        }
        {
            using _t = void (Notification::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Notification::originChanged)) {
                *result = 17;
                return;
            }
        }
        {
            using _t = void (Notification::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Notification::maxContentLinesChanged)) {
                *result = 18;
                return;
            }
        }
        {
            using _t = void (Notification::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Notification::isTransientChanged)) {
                *result = 19;
                return;
            }
        }
        {
            using _t = void (Notification::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Notification::progressChanged)) {
                *result = 20;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<Notification *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->category(); break;
        case 1: *reinterpret_cast< QString*>(_v) = _t->appName(); break;
        case 2: *reinterpret_cast< quint32*>(_v) = _t->replacesId(); break;
        case 3: *reinterpret_cast< QString*>(_v) = _t->icon(); break;
        case 4: *reinterpret_cast< QString*>(_v) = _t->appIcon(); break;
        case 5: *reinterpret_cast< QString*>(_v) = _t->summary(); break;
        case 6: *reinterpret_cast< QString*>(_v) = _t->body(); break;
        case 7: *reinterpret_cast< Urgency*>(_v) = _t->urgency(); break;
        case 8: *reinterpret_cast< qint32*>(_v) = _t->expireTimeout(); break;
        case 9: *reinterpret_cast< QDateTime*>(_v) = _t->timestamp(); break;
        case 10: *reinterpret_cast< QString*>(_v) = _t->previewSummary(); break;
        case 11: *reinterpret_cast< QString*>(_v) = _t->previewBody(); break;
        case 12: *reinterpret_cast< int*>(_v) = _t->itemCount(); break;
        case 13: *reinterpret_cast< QString*>(_v) = _t->remoteDBusCallServiceName(); break;
        case 14: *reinterpret_cast< QString*>(_v) = _t->remoteDBusCallObjectPath(); break;
        case 15: *reinterpret_cast< QString*>(_v) = _t->remoteDBusCallInterface(); break;
        case 16: *reinterpret_cast< QString*>(_v) = _t->remoteDBusCallMethodName(); break;
        case 17: *reinterpret_cast< QVariantList*>(_v) = _t->remoteDBusCallArguments(); break;
        case 18: *reinterpret_cast< QVariantList*>(_v) = _t->remoteActions(); break;
        case 19: *reinterpret_cast< QString*>(_v) = _t->origin(); break;
        case 20: *reinterpret_cast< int*>(_v) = _t->maxContentLines(); break;
        case 21: *reinterpret_cast< bool*>(_v) = _t->isTransient(); break;
        case 22: *reinterpret_cast< QVariant*>(_v) = _t->progress(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<Notification *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setCategory(*reinterpret_cast< QString*>(_v)); break;
        case 1: _t->setAppName(*reinterpret_cast< QString*>(_v)); break;
        case 2: _t->setReplacesId(*reinterpret_cast< quint32*>(_v)); break;
        case 3: _t->setIcon(*reinterpret_cast< QString*>(_v)); break;
        case 4: _t->setAppIcon(*reinterpret_cast< QString*>(_v)); break;
        case 5: _t->setSummary(*reinterpret_cast< QString*>(_v)); break;
        case 6: _t->setBody(*reinterpret_cast< QString*>(_v)); break;
        case 7: _t->setUrgency(*reinterpret_cast< Urgency*>(_v)); break;
        case 8: _t->setExpireTimeout(*reinterpret_cast< qint32*>(_v)); break;
        case 9: _t->setTimestamp(*reinterpret_cast< QDateTime*>(_v)); break;
        case 10: _t->setPreviewSummary(*reinterpret_cast< QString*>(_v)); break;
        case 11: _t->setPreviewBody(*reinterpret_cast< QString*>(_v)); break;
        case 12: _t->setItemCount(*reinterpret_cast< int*>(_v)); break;
        case 13: _t->setRemoteDBusCallServiceName(*reinterpret_cast< QString*>(_v)); break;
        case 14: _t->setRemoteDBusCallObjectPath(*reinterpret_cast< QString*>(_v)); break;
        case 15: _t->setRemoteDBusCallInterface(*reinterpret_cast< QString*>(_v)); break;
        case 16: _t->setRemoteDBusCallMethodName(*reinterpret_cast< QString*>(_v)); break;
        case 17: _t->setRemoteDBusCallArguments(*reinterpret_cast< QVariantList*>(_v)); break;
        case 18: _t->setRemoteActions(*reinterpret_cast< QVariantList*>(_v)); break;
        case 19: _t->setOrigin(*reinterpret_cast< QString*>(_v)); break;
        case 20: _t->setMaxContentLines(*reinterpret_cast< int*>(_v)); break;
        case 21: _t->setIsTransient(*reinterpret_cast< bool*>(_v)); break;
        case 22: _t->setProgress(*reinterpret_cast< QVariant*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
        Notification *_t = static_cast<Notification *>(_o);
        (void)_t;
        switch (_id) {
        case 22: _t->resetProgress(); break;
        default: break;
        }
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject Notification::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_Notification.data,
    qt_meta_data_Notification,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Notification::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Notification::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Notification.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Notification::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 30)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 30;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 30)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 30;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 23;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 23;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 23;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 23;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 23;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Notification::clicked()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Notification::closed(uint _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Notification::categoryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Notification::appNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Notification::replacesIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Notification::iconChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Notification::appIconChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Notification::summaryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Notification::bodyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Notification::urgencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Notification::expireTimeoutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Notification::timestampChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void Notification::previewSummaryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void Notification::previewBodyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void Notification::itemCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void Notification::remoteActionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void Notification::remoteDBusCallChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void Notification::originChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void Notification::maxContentLinesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void Notification::isTransientChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void Notification::progressChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
